@@ -1,8 +1,12 @@
-class ArrayException(Exception):
+class RegionException(Exception):
     pass
 
 
-class ScaledException(Exception):
+class FrameException(Exception):
+    pass
+
+
+class ArrayException(Exception):
     pass
 
 
@@ -14,7 +18,7 @@ class KernelException(Exception):
     pass
 
 
-class ConvolutionException(Exception):
+class ConvolverException(Exception):
     pass
 
 
@@ -36,3 +40,7 @@ class PixelizationException(Exception):
 
 class InversionException(Exception):
     pass
+
+
+class PlottingException(Exception):
+    pass
