@@ -1,6 +1,6 @@
-from .grid import Grid, GridSparse, GridTransformed, GridTransformedNumpy, MaskedGrid
+from .grids import Grid, GridSparse, GridTransformed, GridTransformedNumpy
 from .iterate import GridIterate
 from .interpolate import GridInterpolate
-from .coordinates import GridCoordinates
+from .coordinates import GridCoordinates, GridCoordinatesUniform
 from .pixelization import GridRectangular, GridVoronoi
 from .decorators import *
