@@ -2,6 +2,7 @@ import numpy as np
 
 import autoarray as aa
 from autoarray.structures import grids
+from autoarray.structures.grids import decorators
 
 
 ### Grids ###
@@ -108,7 +109,7 @@ class MockGridLikeIteratorObj:
         cos_theta, sin_theta = self.grid_angle_to_profile(grid_thetas=grid_thetas)
         return np.multiply(radius[:, None], np.vstack((sin_theta, cos_theta)).T)
 
-    @grids.grid_like_to_structure
+    @decorators.grid_like_to_structure
     def ndarray_1d_from_grid(self, grid):
         grid_radii = self.grid_to_grid_radii(grid=grid)
         return np.exp(
@@ -118,13 +119,13 @@ class MockGridLikeIteratorObj:
             )
         )
 
-    @grids.grid_like_to_structure
+    @decorators.grid_like_to_structure
     def ndarray_2d_from_grid(self, grid):
         return self.grid_to_grid_cartesian(
             grid=grid, radius=np.full(grid.shape[0], 2.0)
         )
 
-    @grids.grid_like_to_structure_list
+    @decorators.grid_like_to_structure_list
     def ndarray_1d_list_from_grid(self, grid):
         grid_radii = self.grid_to_grid_radii(grid=grid)
         return [
@@ -136,7 +137,7 @@ class MockGridLikeIteratorObj:
             )
         ]
 
-    @grids.grid_like_to_structure_list
+    @decorators.grid_like_to_structure_list
     def ndarray_2d_list_from_grid(self, grid):
         return [
             self.grid_to_grid_cartesian(grid=grid, radius=np.full(grid.shape[0], 2.0))
@@ -147,19 +148,19 @@ class MockGridLikeObj:
     def __init__(self):
         pass
 
-    @grids.grid_like_to_structure
+    @decorators.grid_like_to_structure
     def ndarray_1d_from_grid(self, grid):
         return np.ones(shape=grid.shape[0])
 
-    @grids.grid_like_to_structure
+    @decorators.grid_like_to_structure
     def ndarray_2d_from_grid(self, grid):
         return np.multiply(2.0, grid)
 
-    @grids.grid_like_to_structure_list
+    @decorators.grid_like_to_structure_list
     def ndarray_1d_list_from_grid(self, grid):
         return [np.ones(shape=grid.shape[0]), 2.0 * np.ones(shape=grid.shape[0])]
 
-    @grids.grid_like_to_structure_list
+    @decorators.grid_like_to_structure_list
     def ndarray_2d_list_from_grid(self, grid):
         return [np.multiply(1.0, grid), np.multiply(2.0, grid)]
 
@@ -171,7 +172,7 @@ class MockGridRadialMinimum:
     def grid_to_grid_radii(self, grid):
         return np.sqrt(np.add(np.square(grid[:, 0]), np.square(grid[:, 1])))
 
-    @grids.relocate_to_radial_minimum
+    @decorators.relocate_to_radial_minimum
     def deflections_from_grid(self, grid):
         return grid
 
